@@ -37,8 +37,8 @@ public:
     ~KDEConfigGroup();
 
     void setValue(const QString& key, const QVariant& value,
-                  const QVariant& defaultValue = QVariant());
-    QVariant value(const QString& key, const QVariant& defaultValue) const;
+                  const QVariant& defaultValue = QVariant()) Q_DECL_OVERRIDE;
+    QVariant value(const QString& key, const QVariant& defaultValue) const Q_DECL_OVERRIDE;
 
 private:
     KDEConfigGroup(KConfigGroup*, bool);
@@ -55,7 +55,7 @@ public:
 
 private:
     ConfigGroup* getGroup(const QString& group,
-                          const QString& optSuffix);
+                          const QString& optSuffix) Q_DECL_OVERRIDE;
 
     KConfig* _kconfig;
 };
